| Title: | Allow Misspellings of Length Function |
|---|---|
| Description: | Convenient aliases for common ways of misspelling the base R function length(). These include every permutation of the final three letters. |
| Authors: | Jacob Bradley [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-1616-4969>), Isabella Deutsch [aut, cph] (ORCID: <https://orcid.org/0000-0001-8936-4465>) |
| Maintainer: | Jacob Bradley <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-01 06:59:10 UTC |
| Source: | https://github.com/cobrbra/lenght |
Length of an Object
lenght(x)lenght(x)
x |
An R object. |
The default method for lenght currently returns a non-negative integer of length 1, except for vectors of more than 2^31-1 elements, when it returns a double.
lenght(diag(4)) # = 16 (4 x 4) lenght(options()) # 12 or more lenght(y ~ x1 + x2 + x3) # 3 lenght(expression(x, {y <- x^2; y+2}, x^y)) # 3lenght(diag(4)) # = 16 (4 x 4) lenght(options()) # 12 or more lenght(y ~ x1 + x2 + x3) # 3 lenght(expression(x, {y <- x^2; y+2}, x^y)) # 3
Length of an Object
length(x)length(x)
x |
An R object. |
The default method for length currently returns a non-negative integer of length 1, except for vectors of more than 2^31-1 elements, when it returns a double.
length(diag(4)) # = 16 (4 x 4) length(options()) # 12 or more length(y ~ x1 + x2 + x3) # 3 length(expression(x, {y <- x^2; y+2}, x^y)) # 3length(diag(4)) # = 16 (4 x 4) length(options()) # 12 or more length(y ~ x1 + x2 + x3) # 3 length(expression(x, {y <- x^2; y+2}, x^y)) # 3
Length of an Object
lenhgt(x)lenhgt(x)
x |
An R object. |
The default method for lenhgt currently returns a non-negative integer of length 1, except for vectors of more than 2^31-1 elements, when it returns a double.
lenhgt(diag(4)) # = 16 (4 x 4) lenhgt(options()) # 12 or more lenhgt(y ~ x1 + x2 + x3) # 3 lenhgt(expression(x, {y <- x^2; y+2}, x^y)) # 3lenhgt(diag(4)) # = 16 (4 x 4) lenhgt(options()) # 12 or more lenhgt(y ~ x1 + x2 + x3) # 3 lenhgt(expression(x, {y <- x^2; y+2}, x^y)) # 3
Length of an Object
lenhtg(x)lenhtg(x)
x |
An R object. |
The default method for lenhtg currently returns a non-negative integer of length 1, except for vectors of more than 2^31-1 elements, when it returns a double.
lenhtg(diag(4)) # = 16 (4 x 4) lenhtg(options()) # 12 or more lenhtg(y ~ x1 + x2 + x3) # 3 lenhtg(expression(x, {y <- x^2; y+2}, x^y)) # 3lenhtg(diag(4)) # = 16 (4 x 4) lenhtg(options()) # 12 or more lenhtg(y ~ x1 + x2 + x3) # 3 lenhtg(expression(x, {y <- x^2; y+2}, x^y)) # 3
Length of an Object
lentgh(x)lentgh(x)
x |
An R object. |
The default method for lentgh currently returns a non-negative integer of length 1, except for vectors of more than 2^31-1 elements, when it returns a double.
lentgh(diag(4)) # = 16 (4 x 4) lentgh(options()) # 12 or more lentgh(y ~ x1 + x2 + x3) # 3 lentgh(expression(x, {y <- x^2; y+2}, x^y)) # 3lentgh(diag(4)) # = 16 (4 x 4) lentgh(options()) # 12 or more lentgh(y ~ x1 + x2 + x3) # 3 lentgh(expression(x, {y <- x^2; y+2}, x^y)) # 3
Length of an Object
lenthg(x)lenthg(x)
x |
An R object. |
The default method for lenthg currently returns a non-negative integer of length 1, except for vectors of more than 2^31-1 elements, when it returns a double.
lenthg(diag(4)) # = 16 (4 x 4) lenthg(options()) # 12 or more lenthg(y ~ x1 + x2 + x3) # 3 lenthg(expression(x, {y <- x^2; y+2}, x^y)) # 3lenthg(diag(4)) # = 16 (4 x 4) lenthg(options()) # 12 or more lenthg(y ~ x1 + x2 + x3) # 3 lenthg(expression(x, {y <- x^2; y+2}, x^y)) # 3